==> bellsoft-jdk21.0.9+11-src-full.tar.gz: jdk-21.0.9-full/openjfx/modules/javafx.base/src/test/java/test/javafx/event/EventTypeConcurrencyTest.java <==
/*
 * Copyright (c) 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package test.javafx.event;

import static org.junit.jupiter.api.Assertions.fail;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;

import javafx.event.Event;
import javafx.event.EventType;
import org.junit.jupiter.api.Test;

/**
 * Developers should be able to create EventTypes in background thread(s).
 */
public class EventTypeConcurrencyTest {
    @Test
    public void concurrentInitialization() {
        int N = 1_000;
        ExecutorService executor = Executors.newCachedThreadPool();
        try {
            try {
                ArrayList<Callable<Object>> runs = new ArrayList<>(N);
                for (int i = 0; i < N; i++) {
                    String name = "TEST" + i;
                    runs.add(() -> {
                        return new EventType<>(Event.ANY, name);
                    });
                }

                List<Future<Object>> futures = executor.invokeAll(runs);

                for (Future<Object> future : futures) {
                    future.get();
                }
            } catch (Throwable e) {
                fail(e);
            }
        } finally {
            executor.shutdownNow();
        }
    }
}

==> bellsoft-jdk25.0.2+12-src-full.tar.gz: jdk-25.0.2-full/openjfx/modules/javafx.base/src/test/java/test/javafx/event/EventTypeConcurrencyTest.java <==
/*
 * Copyright (c) 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package test.javafx.event;

import static org.junit.jupiter.api.Assertions.fail;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.Callable;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import javafx.event.Event;
import javafx.event.EventType;
import org.junit.jupiter.api.Test;

/**
 * Developers should be able to create EventTypes in background thread(s).
 */
public class EventTypeConcurrencyTest {
    @Test
    public void concurrentInitialization() {
        int N = 1_000;
        try (var executor = Executors.newCachedThreadPool()) {
            try {
                ArrayList<Callable<Object>> runs = new ArrayList<>(N);
                for (int i = 0; i < N; i++) {
                    String name = "TEST" + i;
                    runs.add(() -> {
                        return new EventType<>(Event.ANY, name);
                    });
                }

                List<Future<Object>> futures = executor.invokeAll(runs);

                for (Future<Object> future : futures) {
                    future.get();
                }
            } catch (Throwable e) {
                fail(e);
            }
        }
    }
}
